==> cocobits-1.1.2.tgz: package/README.md <==
<div align="center">
<img width="64" height="64" src="img/cocobits_dark_64px.png" alt="Cocobits icon">
<h1>Cocobits</h1>
</div>

<p align="center">
    <a aria-label="npm package" href="https://www.npmjs.com/package/cocobits">
        <img alt="" src="https://img.shields.io/npm/v/cocobits.svg">
    </a>
    <a aria-label="license" href="https://img.shields.io/badge/license-MIT-green">
    <img src="https://img.shields.io/static/v1?label=license&message=MIT&color=green">
    </a>
</p>

Cocobits is a responsive CSS foundational system to build elegant web applications. Influenced by object-oriented CSS principles and functional CSS, interchangeable utility classes allow flexibility and consistency for any web application.

Cocobits uses SASS variables and mixins and strives to meet the highest WCAG accessibility standards.

## Highlights  

- Responsive, mobile-first and accessible by default
- Flexible and interchangeable utility classes
- Base-8 spacing for consistency and dynamic vertical and horizontal rhythm
- Font-size, line-height and weight options for readability
- Color system for meaningful content and interaction signals
- Source files written in `Sass` using `SCSS` syntax

## Install

### npm

After installing npm and node, you can install `cocobits` with command:

```terminal
$ npm install cocobits
```

### Quick Start
Include the following link in the head of your base HTML file:
```HTML
<link rel="stylesheet" href="https://unpkg.com/cocobits/css/cocobits.min.css">
```

## Documentation

The Cocobits documentation is available at: [cocobits.github.io](https://cocobits.github.io/)

## Licence  

[MIT](LICENSE)

==> cocobits-2.0.0.tgz: package/README.md <==
<div align="center">
<img width="64" height="64" src="img/cocobits_dark_64px.png" alt="Cocobits icon">
<h1>Cocobits</h1>
</div>

<p align="center">
    <a aria-label="npm package" href="https://www.npmjs.com/package/cocobits">
        <img alt="" src="https://img.shields.io/npm/v/cocobits.svg">
    </a>
    <a aria-label="license" href="https://img.shields.io/badge/license-MIT-green">
    <img src="https://img.shields.io/static/v1?label=license&message=MIT&color=green">
    </a>
</p>

Cocobits is a responsive CSS foundational system to build elegant web applications. Influenced by object-oriented CSS principles and functional CSS, interchangeable utility classes allow flexibility and consistency for any web application.

Cocobits uses SASS variables and mixins and strives to meet the highest WCAG accessibility standards.

## Highlights  

- Responsive, mobile-first and accessible by default
- Flexible and interchangeable utility classes
- Base-8 spacing for consistency and dynamic vertical and horizontal rhythm
- Font-size, line-height and weight options for readability
- Color system for meaningful content and interaction signals
- Source files written in `Sass` using `SCSS` syntax

## Install

### npm

After installing npm and node, you can install `cocobits` with command:

```terminal
$ npm install cocobits
```

### Quick Start
Include the following link in the head of your base HTML file:
```HTML
<link rel="stylesheet" href="https://unpkg.com/cocobits/dist/css/cocobits.min.css">
```

## Documentation

The Cocobits documentation is available at: [cocobits.github.io](https://cocobits.github.io/)

## Licence  

[MIT](LICENSE)
